"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.PipelineNode = void 0;
const react_1 = __importDefault(require("react"));
const base_ui_surfaces_card_1 = require("@teambit/base-ui.surfaces.card");
const design_ui_styles_ellipsis_1 = require("@teambit/design.ui.styles.ellipsis");
const classnames_1 = __importDefault(require("classnames"));
const design_ui_tooltip_1 = require("@teambit/design.ui.tooltip");
const component_ui_pipelines_component_pipeline_context_1 = require("@teambit/component.ui.pipelines.component-pipeline-context");
const component_ui_pipelines_component_pipeline_utils_1 = require("@teambit/component.ui.pipelines.component-pipeline-utils");
const react_flow_renderer_1 = require("react-flow-renderer");
const pipeline_node_module_scss_1 = __importDefault(require("./pipeline-node.module.scss"));
function PipelineNode(props) {
    const { id, isConnectable, data: { id: taskId, name: taskName, duration, warnings, errors, artifact }, } = props;
    const icon = 'https://static.bit.dev/extensions-icons/react.svg';
    const componentPipelineContext = (0, component_ui_pipelines_component_pipeline_context_1.useComponentPipelineContext)();
    const isSelected = (componentPipelineContext === null || componentPipelineContext === void 0 ? void 0 : componentPipelineContext.selectedPipelineId) === id;
    const onPipelineNodeClicked = () => {
        const updatedId = isSelected ? undefined : id;
        componentPipelineContext === null || componentPipelineContext === void 0 ? void 0 : componentPipelineContext.setSelectedPipelineId(updatedId);
    };
    const showErrorStatus = errors.length > 0;
    const showWarningStaus = !showErrorStatus && warnings.length > 0;
    const Pipeline = (react_1.default.createElement("div", { key: `artifact-node-${id}` },
        react_1.default.createElement(react_flow_renderer_1.Handle, { type: "target", position: react_flow_renderer_1.Position.Left, style: { background: '#555' }, isConnectable: isConnectable }),
        react_1.default.createElement(react_flow_renderer_1.Handle, { type: "source", position: react_flow_renderer_1.Position.Right, style: { background: '#555' }, isConnectable: isConnectable }),
        react_1.default.createElement(base_ui_surfaces_card_1.Card, { className: (0, classnames_1.default)(pipeline_node_module_scss_1.default.pipelineNode, isSelected && pipeline_node_module_scss_1.default.selected, showWarningStaus && pipeline_node_module_scss_1.default.warning, showErrorStatus && pipeline_node_module_scss_1.default.error), roundness: "small", elevation: "none", onClick: artifact && onPipelineNodeClicked },
            react_1.default.createElement("div", { className: pipeline_node_module_scss_1.default.componentDetailsContainer },
                react_1.default.createElement("div", { className: (0, classnames_1.default)(pipeline_node_module_scss_1.default.componentDetails) }, react_1.default.createElement("img", { src: icon, className: pipeline_node_module_scss_1.default.envIcon })),
                react_1.default.createElement("div", { className: pipeline_node_module_scss_1.default.taskId },
                    react_1.default.createElement("div", { className: (0, classnames_1.default)(pipeline_node_module_scss_1.default.breadcrumbs, design_ui_styles_ellipsis_1.ellipsis) }, taskId))),
            react_1.default.createElement("div", { className: (0, classnames_1.default)(pipeline_node_module_scss_1.default.componentName) },
                react_1.default.createElement("div", { className: (0, classnames_1.default)(pipeline_node_module_scss_1.default.name, design_ui_styles_ellipsis_1.ellipsis) }, taskName),
                react_1.default.createElement("div", { className: (0, classnames_1.default)(pipeline_node_module_scss_1.default.version, design_ui_styles_ellipsis_1.ellipsis) },
                    (0, component_ui_pipelines_component_pipeline_utils_1.calcSeconds)(duration),
                    "s ",
                    (0, component_ui_pipelines_component_pipeline_utils_1.calcMilliseconds)(duration),
                    "ms")))));
    if (!artifact)
        return (react_1.default.createElement(design_ui_tooltip_1.Tooltip, { placement: "bottom", content: 'no artifacts' }, Pipeline));
    return Pipeline;
}
exports.PipelineNode = PipelineNode;
exports.default = PipelineNode;
//# sourceMappingURL=pipeline-node.js.map